@@ -1,5 +1,5 @@
 package App::vaporcalc::Result;
-$App::vaporcalc::Result::VERSION = '0.003002';
+$App::vaporcalc::Result::VERSION = '0.003003';
 use Defaults::Modern
   -with_types => [ 'App::vaporcalc::Types' ];
 
@@ -41,9 +41,7 @@ method flavor_total {
   $flavor_ml
 }
 
-method total {
-  $self->vg + $self->pg + $self->nic + $self->flavor_total;
-}
+method total { $self->vg + $self->pg + $self->nic + $self->flavor_total }
 
 method TO_JSON {
   +{
